==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d6/d08/structWindow.js <==
var structWindow =
[
    [ "Window", "d6/d08/structWindow.html#a7c66af885d81231f222f05db62a1243e", null ],
    [ "~Window", "d6/d08/structWindow.html#a245d821e6016fa1f6970ccbbedd635f6", null ],
    [ "ApplyDefaults", "d6/d08/structWindow.html#a13b3fe389f9c3e9b78fa84bb4dd96ec0", null ],
    [ "CreateNestedTree", "d6/d08/structWindow.html#a431ffd114d065f03bf0ad5472072987c", null ],
    [ "DeleteChildWindows", "d6/d08/structWindow.html#a52d07ad1eef2e218fe712af33c476139", null ],
    [ "DisableAllWidgetHighlight", "d6/d08/structWindow.html#ae69e3ab93de6f7b2feaf10fa38c9a4c3", null ],
    [ "DisableWidget", "d6/d08/structWindow.html#ad91095b2ae58cb581c651d3e1f541610", null ],
    [ "DrawSortButtonState", "d6/d08/structWindow.html#a85e53f6c1702af83fb0dc42fef2a1c9f", null ],
    [ "DrawViewport", "d6/d08/structWindow.html#a78de6e16ee02f559a386c1c826eb6d99", null ],
    [ "DrawWidget", "d6/d08/structWindow.html#abdc0d18b8d1cad036c14fdeed0fb6959", null ],
    [ "DrawWidgets", "d6/d08/structWindow.html#a1a021d1e021d58641be45ad5d4a75e75", null ],
    [ "EnableWidget", "d6/d08/structWindow.html#aa62109b7494684318cdbba17cc82ec90", null ],
    [ "FindWindowPlacementAndResize", "d6/d08/structWindow.html#afda2053b9141b3a8599d40527bb712ff", null ],
    [ "FinishInitNested", "d6/d08/structWindow.html#a10c7c1f99cc505fbf4c052e2c86021fc", null ],
    [ "GetCaret", "d6/d08/structWindow.html#af03277a1b2d144623a3e16bf83e71950", null ],
    [ "GetCaretPosition", "d6/d08/structWindow.html#a97078f45b531954464d303ce5250eb26", null ],
    [ "GetFocusedText", "d6/d08/structWindow.html#ab763696a7b3f88c6f1f52f85543bf282", null ],
    [ "GetMarkedText", "d6/d08/structWindow.html#a7ff7ccc6f8eb5963fdb934973b81d2c9", null ],
    [ "GetQueryString", "d6/d08/structWindow.html#a61e02ed9eefff2cfb996a57c4f104e19", null ],
    [ "GetQueryString", "d6/d08/structWindow.html#a330519d4a6a4d22f3fde30798c473b73", null ],
    [ "GetRowFromWidget", "d6/d08/structWindow.html#a7a3a3da4f5e857c0088761a92efd6f9a", null ],
    [ "GetScrollbar", "d6/d08/structWindow.html#a635d082d2f20926d5f4d998ccd767904", null ],
    [ "GetScrollbar", "d6/d08/structWindow.html#a09395357fc068f44a1f1bab8f75b42f1", null ],
    [ "GetTextBoundingRect", "d6/d08/structWindow.html#ad9671182fe2a3b4a5c69689d0ec2ba4e", null ],
    [ "GetTextCharacterAtPosition", "d6/d08/structWindow.html#ac2afc3fe14e8ec208d8b4b712e0e09cc", null ],
    [ "GetWidget", "d6/d08/structWindow.html#a8fe82ff01c7760e2b8b1736ece21faa4", null ],
    [ "GetWidget", "d6/d08/structWindow.html#a88966c6e4be68890d8e9d7b9a971fc11", null ],
    [ "GetWidget", "d6/d08/structWindow.html#a78394e74c95b9a0c25181e84d1ed98d2", null ],
    [ "HandleButtonClick", "d6/d08/structWindow.html#aa7caad580f027982e5bb5a8fc0460f11", null ],
    [ "HandleEditBoxKey", "d6/d08/structWindow.html#a9ed3e17e1f86910d60088c9a733cd519", null ],
    [ "InitializeData", "d6/d08/structWindow.html#abc2162813e1809d4bdee213a928f5155", null ],
    [ "InitializePositionSize", "d6/d08/structWindow.html#a15b8023dfeef55aeab631935fdbf7ff5", null ],
    [ "InitNested", "d6/d08/structWindow.html#acbd4fcdce10cae4a20e3ad3e42b9f8da", null ],
    [ "InsertTextString", "d6/d08/structWindow.html#a8065b7a0b7bb8b68f393664e2e739de9", null ],
    [ "InvalidateData", "d6/d08/structWindow.html#a1f5d3e8356b0a957314a6d769a195928", null ],
    [ "IsNewGRFInspectable", "d6/d08/structWindow.html#a589a1d85eb8a8f7b1c1cbc56fca6dcd6", null ],
    [ "IsShaded", "d6/d08/structWindow.html#aa46d6def28177312b4dfa7ea3c089a20", null ],
    [ "IsWidgetDisabled", "d6/d08/structWindow.html#a15a71ecf60f40e1193f2095135de9d26", null ],
    [ "IsWidgetFocused", "d6/d08/structWindow.html#a5de5053c8a1a598627dff650d9f46ad2", null ],
    [ "IsWidgetGloballyFocused", "d6/d08/structWindow.html#ae600d86daf0c6cbb62593ece9d016b90", null ],
    [ "IsWidgetHighlighted", "d6/d08/structWindow.html#a4a3b719223ff37c208b55cf24cee4029", null ],
    [ "IsWidgetLowered", "d6/d08/structWindow.html#a4ed0e49ea8277405b494ef229aea97dc", null ],
    [ "LowerWidget", "d6/d08/structWindow.html#a2f596dc09e9896187b59318a8cb8f74e", null ],
    [ "OnClick", "d6/d08/structWindow.html#ab59662c42ebabecc902dc08b6ba24c29", null ],
    [ "OnCTRLStateChange", "d6/d08/structWindow.html#ac17685246ea87fe09ac35442cab4976a", null ],
    [ "OnDragDrop", "d6/d08/structWindow.html#a1940599655eb1a2f24c22e691fb951d6", null ],
    [ "OnDropdownClose", "d6/d08/structWindow.html#a0c80b94d80b892d78d62a0f67320a05a", null ],
    [ "OnDropdownSelect", "d6/d08/structWindow.html#a9c0b1a368627c5e488ad20a79a1a7e96", null ],
    [ "OnEditboxChanged", "d6/d08/structWindow.html#a78e5b2f75d0fd1dc8f6615bef777beb0", null ],
    [ "OnFocus", "d6/d08/structWindow.html#a7bd493174edb896715ecd2aab26f7eda", null ],
    [ "OnFocusLost", "d6/d08/structWindow.html#a288b584c58e02e039bdb5a0ff376eaf0", null ],
    [ "OnGameTick", "d6/d08/structWindow.html#a316e12a44be29af32b16ca1a1d806791", null ],
    [ "OnHotkey", "d6/d08/structWindow.html#add1853b00939794daa153e29a92b2b58", null ],
    [ "OnHover", "d6/d08/structWindow.html#a35954762e321a5d4d8aecc8794d961c7", null ],
    [ "OnHundredthTick", "d6/d08/structWindow.html#a11f78b97a52c7ceee365d6cf8360b793", null ],
    [ "OnInit", "d6/d08/structWindow.html#af791c3e010004580275b73e5f1f155a5", null ],
    [ "OnInitialPosition", "d6/d08/structWindow.html#ab200993a6bff9a98eb070043d6544620", null ],
    [ "OnInvalidateData", "d6/d08/structWindow.html#a0ef00203d09aa4eac6940c77f44ca3ad", null ],
    [ "OnKeyPress", "d6/d08/structWindow.html#a84a9ce823ff2c3d0d73c1ac3cb293284", null ],
    [ "OnMouseDrag", "d6/d08/structWindow.html#a40c323c2eed5e49b3e7777911118d5f8", null ],
    [ "OnMouseLoop", "d6/d08/structWindow.html#a49486da0686b1a5dfcf3b991d9693031", null ],
    [ "OnMouseOver", "d6/d08/structWindow.html#a8a96332463b4995a70c468a9dad9f1f3", null ],
    [ "OnMouseWheel", "d6/d08/structWindow.html#a8be12bb25af50ade340e44ccb72ed1e8", null ],
    [ "OnPaint", "d6/d08/structWindow.html#a5749496904ac41a88cbf4e3faaf82a98", null ],
    [ "OnPlaceDrag", "d6/d08/structWindow.html#adc7bfa886209d072ca4d7961238f15c3", null ],
    [ "OnPlaceMouseUp", "d6/d08/structWindow.html#abca3f331a47b9e44b15d6a0de754a01b", null ],
    [ "OnPlaceObject", "d6/d08/structWindow.html#a9f654b77273e23a38059e29b1e8a9005", null ],
    [ "OnPlaceObjectAbort", "d6/d08/structWindow.html#a4da793bcbe0f072436464401a368db4d", null ],
    [ "OnPlacePresize", "d6/d08/structWindow.html#ae8e344a8bd0375c9c248d1b0e1266a24", null ],
    [ "OnQueryTextFinished", "d6/d08/structWindow.html#adec70a63574dfa604d39a915f64e95a5", null ],
    [ "OnRealtimeTick", "d6/d08/structWindow.html#a5b2cff47cab80dc1c31a404cdb83bcea", null ],
    [ "OnResize", "d6/d08/structWindow.html#ac74af034c21814014b3368fbefbc32af", null ],
    [ "OnRightClick", "d6/d08/structWindow.html#af121605d73aab10f9f8a50c035a009aa", null ],
    [ "OnScroll", "d6/d08/structWindow.html#aae267cf23ddb9ce50f3b123a23d845d1", null ],
    [ "OnTimeout", "d6/d08/structWindow.html#ad2ad091a96573f5662d5648e18526aae", null ],
    [ "OnVehicleSelect", "d6/d08/structWindow.html#a516ba3654625778ec351db03eb6f1188", null ],
    [ "operator delete", "d6/d08/structWindow.html#aba76de46233d779c22ff6335a8436d07", null ],
    [ "operator new[]", "d6/d08/structWindow.html#aa5b08117898dd30f2d0265848c0bed5f", null ],
    [ "ProcessHighlightedInvalidations", "d6/d08/structWindow.html#ad879a11bdc4f503ab13c00694b221cd8", null ],
    [ "ProcessScheduledInvalidations", "d6/d08/structWindow.html#a3949b000c62a73a6c610e641d273c174", null ],
    [ "RaiseButtons", "d6/d08/structWindow.html#a85b750cd484cc892c385670c3d52f9d1", null ],
    [ "RaiseWidget", "d6/d08/structWindow.html#a7a853265af3b511d6d1041d92ff891d9", null ],
    [ "ReInit", "d6/d08/structWindow.html#a431d0bf103c8630a7ef2cfcc64ea2a3f", null ],
    [ "SetDirty", "d5/d48/group__dirty.html#ga13b8d49f24a236df46aec49f3ded6c44", null ],
    [ "SetFocusedWidget", "d6/d08/structWindow.html#ae7dbfad05d2e052400cca81a46b98476", null ],
    [ "SetShaded", "d6/d08/structWindow.html#a4b849eb015e0a3c0a4d4b6224de22257", null ],
    [ "SetStringParameters", "d6/d08/structWindow.html#aadbee7a500e8769cf8f825e965960d11", null ],
    [ "SetTimeout", "d6/d08/structWindow.html#aab60b083646b72a1a3cd2e123305ca00", null ],
    [ "SetWhiteBorder", "d6/d08/structWindow.html#a6971b9461d224b88109fa4287359f9a4", null ],
    [ "SetWidgetDirty", "d6/d08/structWindow.html#aef992f30dea8dda32826efc66840a0a0", null ],
    [ "SetWidgetDisabledState", "d6/d08/structWindow.html#ac89138c22872208a10b366c8c6764a98", null ],
    [ "SetWidgetHighlight", "d6/d08/structWindow.html#aa37becb3f13ce53ab0ab51b22d6c5e94", null ],
    [ "SetWidgetLoweredState", "d6/d08/structWindow.html#a783931d0dd4919a7fab5c1e9d455ce4a", null ],
    [ "SetWidgetsDisabledState", "d6/d08/structWindow.html#aa4d302cb15483a360be7ed4621416e4a", null ],
    [ "SetWidgetsLoweredState", "d6/d08/structWindow.html#a4831e4ac0123cb23feebc7ae45ed137e", null ],
    [ "ShowNewGRFInspectWindow", "d6/d08/structWindow.html#a319ec0070ed6948e52d1076e741a8cdf", null ],
    [ "SortButtonWidth", "d6/d08/structWindow.html#a0f894422e1b7ac9ab25a9170fb013d79", null ],
    [ "ToggleWidgetLoweredState", "d6/d08/structWindow.html#afcde2aeacb58a97e7f4187fa9334a633", null ],
    [ "UnfocusFocusedWidget", "d6/d08/structWindow.html#a3e630ff07e9e51aa6c7b48e11a8d71b1", null ],
    [ "UpdateWidgetSize", "d6/d08/structWindow.html#a7ee030c4ab408389a42491b70bacc65a", null ],
    [ "flags", "d6/d08/structWindow.html#ad3670a9f17f5493bdbf395c690310ebe", null ],
    [ "height", "d6/d08/structWindow.html#af0ac1732ca6b79a6f6b78aa344140514", null ],
    [ "left", "d6/d08/structWindow.html#aa128597cbbc824fb1932ee2f854dda76", null ],
    [ "nested_array", "d6/d08/structWindow.html#ae4106a3b9557f33f9b62b020373be685", null ],
    [ "nested_array_size", "d6/d08/structWindow.html#a54293df0251c53e155e5e568e7ccd395", null ],
    [ "nested_focus", "d6/d08/structWindow.html#aad389fdc53e09eb7d931f7d41a7309e6", null ],
    [ "nested_root", "d6/d08/structWindow.html#a4513649ab8b8cd3a9fe3e8d6f1e8d191", null ],
    [ "owner", "d6/d08/structWindow.html#a8a5c12ba5ef69250ca378da49b21713e", null ],
    [ "parent", "d6/d08/structWindow.html#a2194476b8d1e938f195fafa9beee1b85", null ],
    [ "querystrings", "d6/d08/structWindow.html#a2156989ad91ec864c88f5eed8d2c2b80", null ],
    [ "resize", "d6/d08/structWindow.html#a3d9646c995d2a2977a52f8d89f36f4a2", null ],
    [ "scheduled_invalidation_data", "d6/d08/structWindow.html#a139bfb7f3870fe7e44875c9bad944031", null ],
    [ "scrolling_scrollbar", "d6/d08/structWindow.html#ad5cd1dfa19daaca0252700de6c2916af", null ],
    [ "shade_select", "d6/d08/structWindow.html#a14680b07d9572149ff5f47300eb3e311", null ],
    [ "timeout_timer", "d6/d08/structWindow.html#a43cbbcb2e80416715369041bd763acc7", null ],
    [ "top", "d6/d08/structWindow.html#ab18425fd10149e32ab8576d6cfa6e1a1", null ],
    [ "unshaded_size", "d6/d08/structWindow.html#a1ef0f7e6f4ef523922f3eac5d049c438", null ],
    [ "viewport", "d6/d08/structWindow.html#a647c9bfe0023e8c9aa76e73544319b02", null ],
    [ "white_border_timer", "d6/d08/structWindow.html#ae3dc3efddcd745c17f8384441b33fe87", null ],
    [ "width", "d6/d08/structWindow.html#af5b1c436782cc9752d386493fbc5dc8c", null ],
    [ "window_class", "d6/d08/structWindow.html#a5a5d76abe3eb83a37ecb1e4fa8ed5111", null ],
    [ "window_desc", "d6/d08/structWindow.html#ac1f9bfef0191a17c228fcb038dadfd99", null ],
    [ "window_number", "d6/d08/structWindow.html#aff1d1a0e903f9e6a9c59ccc0184ff68a", null ],
    [ "z_back", "d6/d08/structWindow.html#a2f9706780aed25bf86e1718ddb4bbda2", null ],
    [ "z_front", "d6/d08/structWindow.html#a74f2285341fa7f0faf98651af3acf73a", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d6/d08/structWindow.js <==
var structWindow =
[
    [ "Window", "d6/d08/structWindow.html#a7c66af885d81231f222f05db62a1243e", null ],
    [ "~Window", "d6/d08/structWindow.html#a245d821e6016fa1f6970ccbbedd635f6", null ],
    [ "ApplyDefaults", "d6/d08/structWindow.html#a13b3fe389f9c3e9b78fa84bb4dd96ec0", null ],
    [ "CreateNestedTree", "d6/d08/structWindow.html#a431ffd114d065f03bf0ad5472072987c", null ],
    [ "DeleteChildWindows", "d6/d08/structWindow.html#a52d07ad1eef2e218fe712af33c476139", null ],
    [ "DisableAllWidgetHighlight", "d6/d08/structWindow.html#ae69e3ab93de6f7b2feaf10fa38c9a4c3", null ],
    [ "DisableWidget", "d6/d08/structWindow.html#ad91095b2ae58cb581c651d3e1f541610", null ],
    [ "DrawSortButtonState", "d6/d08/structWindow.html#a85e53f6c1702af83fb0dc42fef2a1c9f", null ],
    [ "DrawViewport", "d6/d08/structWindow.html#a78de6e16ee02f559a386c1c826eb6d99", null ],
    [ "DrawWidget", "d6/d08/structWindow.html#abdc0d18b8d1cad036c14fdeed0fb6959", null ],
    [ "DrawWidgets", "d6/d08/structWindow.html#a1a021d1e021d58641be45ad5d4a75e75", null ],
    [ "EnableWidget", "d6/d08/structWindow.html#aa62109b7494684318cdbba17cc82ec90", null ],
    [ "FindWindowPlacementAndResize", "d6/d08/structWindow.html#afda2053b9141b3a8599d40527bb712ff", null ],
    [ "FinishInitNested", "d6/d08/structWindow.html#a10c7c1f99cc505fbf4c052e2c86021fc", null ],
    [ "GetCaret", "d6/d08/structWindow.html#af03277a1b2d144623a3e16bf83e71950", null ],
    [ "GetCaretPosition", "d6/d08/structWindow.html#a97078f45b531954464d303ce5250eb26", null ],
    [ "GetFocusedText", "d6/d08/structWindow.html#ab763696a7b3f88c6f1f52f85543bf282", null ],
    [ "GetMarkedText", "d6/d08/structWindow.html#a7ff7ccc6f8eb5963fdb934973b81d2c9", null ],
    [ "GetQueryString", "d6/d08/structWindow.html#a330519d4a6a4d22f3fde30798c473b73", null ],
    [ "GetQueryString", "d6/d08/structWindow.html#a61e02ed9eefff2cfb996a57c4f104e19", null ],
    [ "GetRowFromWidget", "d6/d08/structWindow.html#a7a3a3da4f5e857c0088761a92efd6f9a", null ],
    [ "GetScrollbar", "d6/d08/structWindow.html#a09395357fc068f44a1f1bab8f75b42f1", null ],
    [ "GetScrollbar", "d6/d08/structWindow.html#a635d082d2f20926d5f4d998ccd767904", null ],
    [ "GetTextBoundingRect", "d6/d08/structWindow.html#ad9671182fe2a3b4a5c69689d0ec2ba4e", null ],
    [ "GetTextCharacterAtPosition", "d6/d08/structWindow.html#ac2afc3fe14e8ec208d8b4b712e0e09cc", null ],
    [ "GetWidget", "d6/d08/structWindow.html#a88966c6e4be68890d8e9d7b9a971fc11", null ],
    [ "GetWidget", "d6/d08/structWindow.html#a8fe82ff01c7760e2b8b1736ece21faa4", null ],
    [ "GetWidget", "d6/d08/structWindow.html#a78394e74c95b9a0c25181e84d1ed98d2", null ],
    [ "HandleButtonClick", "d6/d08/structWindow.html#aa7caad580f027982e5bb5a8fc0460f11", null ],
    [ "HandleEditBoxKey", "d6/d08/structWindow.html#a9ed3e17e1f86910d60088c9a733cd519", null ],
    [ "InitializeData", "d6/d08/structWindow.html#abc2162813e1809d4bdee213a928f5155", null ],
    [ "InitializePositionSize", "d6/d08/structWindow.html#a15b8023dfeef55aeab631935fdbf7ff5", null ],
    [ "InitNested", "d6/d08/structWindow.html#acbd4fcdce10cae4a20e3ad3e42b9f8da", null ],
    [ "InsertTextString", "d6/d08/structWindow.html#a8065b7a0b7bb8b68f393664e2e739de9", null ],
    [ "InvalidateData", "d6/d08/structWindow.html#a1f5d3e8356b0a957314a6d769a195928", null ],
    [ "IsNewGRFInspectable", "d6/d08/structWindow.html#a589a1d85eb8a8f7b1c1cbc56fca6dcd6", null ],
    [ "IsShaded", "d6/d08/structWindow.html#aa46d6def28177312b4dfa7ea3c089a20", null ],
    [ "IsWidgetDisabled", "d6/d08/structWindow.html#a15a71ecf60f40e1193f2095135de9d26", null ],
    [ "IsWidgetFocused", "d6/d08/structWindow.html#a5de5053c8a1a598627dff650d9f46ad2", null ],
    [ "IsWidgetGloballyFocused", "d6/d08/structWindow.html#ae600d86daf0c6cbb62593ece9d016b90", null ],
    [ "IsWidgetHighlighted", "d6/d08/structWindow.html#a4a3b719223ff37c208b55cf24cee4029", null ],
    [ "IsWidgetLowered", "d6/d08/structWindow.html#a4ed0e49ea8277405b494ef229aea97dc", null ],
    [ "LowerWidget", "d6/d08/structWindow.html#a2f596dc09e9896187b59318a8cb8f74e", null ],
    [ "OnClick", "d6/d08/structWindow.html#ab59662c42ebabecc902dc08b6ba24c29", null ],
    [ "OnCTRLStateChange", "d6/d08/structWindow.html#ac17685246ea87fe09ac35442cab4976a", null ],
    [ "OnDragDrop", "d6/d08/structWindow.html#a1940599655eb1a2f24c22e691fb951d6", null ],
    [ "OnDropdownClose", "d6/d08/structWindow.html#a0c80b94d80b892d78d62a0f67320a05a", null ],
    [ "OnDropdownSelect", "d6/d08/structWindow.html#a9c0b1a368627c5e488ad20a79a1a7e96", null ],
    [ "OnEditboxChanged", "d6/d08/structWindow.html#a78e5b2f75d0fd1dc8f6615bef777beb0", null ],
    [ "OnFocus", "d6/d08/structWindow.html#aca61645f4bc1b91af2d4c62c7995078d", null ],
    [ "OnFocusLost", "d6/d08/structWindow.html#a288b584c58e02e039bdb5a0ff376eaf0", null ],
    [ "OnGameTick", "d6/d08/structWindow.html#a316e12a44be29af32b16ca1a1d806791", null ],
    [ "OnHotkey", "d6/d08/structWindow.html#add1853b00939794daa153e29a92b2b58", null ],
    [ "OnHover", "d6/d08/structWindow.html#a35954762e321a5d4d8aecc8794d961c7", null ],
    [ "OnHundredthTick", "d6/d08/structWindow.html#a11f78b97a52c7ceee365d6cf8360b793", null ],
    [ "OnInit", "d6/d08/structWindow.html#af791c3e010004580275b73e5f1f155a5", null ],
    [ "OnInitialPosition", "d6/d08/structWindow.html#ab200993a6bff9a98eb070043d6544620", null ],
    [ "OnInvalidateData", "d6/d08/structWindow.html#a0ef00203d09aa4eac6940c77f44ca3ad", null ],
    [ "OnKeyPress", "d6/d08/structWindow.html#a84a9ce823ff2c3d0d73c1ac3cb293284", null ],
    [ "OnMouseDrag", "d6/d08/structWindow.html#a40c323c2eed5e49b3e7777911118d5f8", null ],
    [ "OnMouseLoop", "d6/d08/structWindow.html#a49486da0686b1a5dfcf3b991d9693031", null ],
    [ "OnMouseOver", "d6/d08/structWindow.html#a8a96332463b4995a70c468a9dad9f1f3", null ],
    [ "OnMouseWheel", "d6/d08/structWindow.html#a8be12bb25af50ade340e44ccb72ed1e8", null ],
    [ "OnPaint", "d6/d08/structWindow.html#a5749496904ac41a88cbf4e3faaf82a98", null ],
    [ "OnPlaceDrag", "d6/d08/structWindow.html#adc7bfa886209d072ca4d7961238f15c3", null ],
    [ "OnPlaceMouseUp", "d6/d08/structWindow.html#abca3f331a47b9e44b15d6a0de754a01b", null ],
    [ "OnPlaceObject", "d6/d08/structWindow.html#a9f654b77273e23a38059e29b1e8a9005", null ],
    [ "OnPlaceObjectAbort", "d6/d08/structWindow.html#a4da793bcbe0f072436464401a368db4d", null ],
    [ "OnPlacePresize", "d6/d08/structWindow.html#ae8e344a8bd0375c9c248d1b0e1266a24", null ],
    [ "OnQueryTextFinished", "d6/d08/structWindow.html#adec70a63574dfa604d39a915f64e95a5", null ],
    [ "OnRealtimeTick", "d6/d08/structWindow.html#a5b2cff47cab80dc1c31a404cdb83bcea", null ],
    [ "OnResize", "d6/d08/structWindow.html#ac74af034c21814014b3368fbefbc32af", null ],
    [ "OnRightClick", "d6/d08/structWindow.html#af121605d73aab10f9f8a50c035a009aa", null ],
    [ "OnScroll", "d6/d08/structWindow.html#aae267cf23ddb9ce50f3b123a23d845d1", null ],
    [ "OnTimeout", "d6/d08/structWindow.html#ad2ad091a96573f5662d5648e18526aae", null ],
    [ "OnTooltip", "d6/d08/structWindow.html#a8d0f03dd870eb3c5fe16e5f4571c5ff8", null ],
    [ "OnVehicleSelect", "d6/d08/structWindow.html#a516ba3654625778ec351db03eb6f1188", null ],
    [ "operator delete", "d6/d08/structWindow.html#aba76de46233d779c22ff6335a8436d07", null ],
    [ "operator new[]", "d6/d08/structWindow.html#aa5b08117898dd30f2d0265848c0bed5f", null ],
    [ "ProcessHighlightedInvalidations", "d6/d08/structWindow.html#ad879a11bdc4f503ab13c00694b221cd8", null ],
    [ "ProcessScheduledInvalidations", "d6/d08/structWindow.html#a3949b000c62a73a6c610e641d273c174", null ],
    [ "RaiseButtons", "d6/d08/structWindow.html#a85b750cd484cc892c385670c3d52f9d1", null ],
    [ "RaiseWidget", "d6/d08/structWindow.html#a7a853265af3b511d6d1041d92ff891d9", null ],
    [ "ReInit", "d6/d08/structWindow.html#a431d0bf103c8630a7ef2cfcc64ea2a3f", null ],
    [ "SetDirty", "d5/d48/group__dirty.html#ga13b8d49f24a236df46aec49f3ded6c44", null ],
    [ "SetFocusedWidget", "d6/d08/structWindow.html#ae7dbfad05d2e052400cca81a46b98476", null ],
    [ "SetShaded", "d6/d08/structWindow.html#a4b849eb015e0a3c0a4d4b6224de22257", null ],
    [ "SetStringParameters", "d6/d08/structWindow.html#aadbee7a500e8769cf8f825e965960d11", null ],
    [ "SetTimeout", "d6/d08/structWindow.html#aab60b083646b72a1a3cd2e123305ca00", null ],
    [ "SetWhiteBorder", "d6/d08/structWindow.html#a6971b9461d224b88109fa4287359f9a4", null ],
    [ "SetWidgetDirty", "d6/d08/structWindow.html#aef992f30dea8dda32826efc66840a0a0", null ],
    [ "SetWidgetDisabledState", "d6/d08/structWindow.html#ac89138c22872208a10b366c8c6764a98", null ],
    [ "SetWidgetHighlight", "d6/d08/structWindow.html#aa37becb3f13ce53ab0ab51b22d6c5e94", null ],
    [ "SetWidgetLoweredState", "d6/d08/structWindow.html#a783931d0dd4919a7fab5c1e9d455ce4a", null ],
    [ "SetWidgetsDisabledState", "d6/d08/structWindow.html#aa4d302cb15483a360be7ed4621416e4a", null ],
    [ "SetWidgetsLoweredState", "d6/d08/structWindow.html#a4831e4ac0123cb23feebc7ae45ed137e", null ],
    [ "ShowNewGRFInspectWindow", "d6/d08/structWindow.html#a319ec0070ed6948e52d1076e741a8cdf", null ],
    [ "SortButtonWidth", "d6/d08/structWindow.html#a0f894422e1b7ac9ab25a9170fb013d79", null ],
    [ "ToggleWidgetLoweredState", "d6/d08/structWindow.html#afcde2aeacb58a97e7f4187fa9334a633", null ],
    [ "UnfocusFocusedWidget", "d6/d08/structWindow.html#a3e630ff07e9e51aa6c7b48e11a8d71b1", null ],
    [ "UpdateWidgetSize", "d6/d08/structWindow.html#a7ee030c4ab408389a42491b70bacc65a", null ],
    [ "flags", "d6/d08/structWindow.html#ad3670a9f17f5493bdbf395c690310ebe", null ],
    [ "height", "d6/d08/structWindow.html#af0ac1732ca6b79a6f6b78aa344140514", null ],
    [ "left", "d6/d08/structWindow.html#aa128597cbbc824fb1932ee2f854dda76", null ],
    [ "mouse_capture_widget", "d6/d08/structWindow.html#a639cede94bbd44d8a599bd874db8c145", null ],
    [ "nested_array", "d6/d08/structWindow.html#ae4106a3b9557f33f9b62b020373be685", null ],
    [ "nested_array_size", "d6/d08/structWindow.html#a54293df0251c53e155e5e568e7ccd395", null ],
    [ "nested_focus", "d6/d08/structWindow.html#aad389fdc53e09eb7d931f7d41a7309e6", null ],
    [ "nested_root", "d6/d08/structWindow.html#a4513649ab8b8cd3a9fe3e8d6f1e8d191", null ],
    [ "owner", "d6/d08/structWindow.html#a8a5c12ba5ef69250ca378da49b21713e", null ],
    [ "parent", "d6/d08/structWindow.html#a2194476b8d1e938f195fafa9beee1b85", null ],
    [ "querystrings", "d6/d08/structWindow.html#a2156989ad91ec864c88f5eed8d2c2b80", null ],
    [ "resize", "d6/d08/structWindow.html#a3d9646c995d2a2977a52f8d89f36f4a2", null ],
    [ "scheduled_invalidation_data", "d6/d08/structWindow.html#abbc0737b6e8851e1564d6763a7a91df2", null ],
    [ "shade_select", "d6/d08/structWindow.html#a14680b07d9572149ff5f47300eb3e311", null ],
    [ "timeout_timer", "d6/d08/structWindow.html#a43cbbcb2e80416715369041bd763acc7", null ],
    [ "top", "d6/d08/structWindow.html#ab18425fd10149e32ab8576d6cfa6e1a1", null ],
    [ "unshaded_size", "d6/d08/structWindow.html#a1ef0f7e6f4ef523922f3eac5d049c438", null ],
    [ "viewport", "d6/d08/structWindow.html#a647c9bfe0023e8c9aa76e73544319b02", null ],
    [ "white_border_timer", "d6/d08/structWindow.html#ae3dc3efddcd745c17f8384441b33fe87", null ],
    [ "width", "d6/d08/structWindow.html#af5b1c436782cc9752d386493fbc5dc8c", null ],
    [ "window_class", "d6/d08/structWindow.html#a5a5d76abe3eb83a37ecb1e4fa8ed5111", null ],
    [ "window_desc", "d6/d08/structWindow.html#ac1f9bfef0191a17c228fcb038dadfd99", null ],
    [ "window_number", "d6/d08/structWindow.html#aff1d1a0e903f9e6a9c59ccc0184ff68a", null ],
    [ "z_back", "d6/d08/structWindow.html#a2f9706780aed25bf86e1718ddb4bbda2", null ],
    [ "z_front", "d6/d08/structWindow.html#a74f2285341fa7f0faf98651af3acf73a", null ]
];
